import socket
import select


import network

class Client:
	def __init__(self, server_ip):
		self.socket = socket.socket()
		self.socket.connect((server_ip, network.default_server_port))
		self.client_id = network.get_client_information(self.socket)
	
	def get_client_id(self):
		return self.client_id
	
	def send_updates(self, ship_index, key_index, is_down):
		network.send_key_information(self.socket, ship_index, key_index, is_down)
	
	def do_frame(self, level, time_passed):
		#process all messages from server
		while True:
			if select.select([self.socket],[],[],0)[0] == []:
				break
			command = network.get_command_code(self.socket)
			if command == network.KEY_UPDATE_CODE:
				#key update
				ship_index, key_index, is_down = network.get_key_information(self.socket)
				level.ships[ship_index].keys_pressed[key_index] = is_down
			elif command == network.SHIP_INFORMATION_CODE:
				#ship information update
				ship_code = network.get_ship_code(self.socket)
				network.get_ship_information(self.socket, level.ships[ship_code])
			elif command == '':
				#connection closed
				raise Exception("Connection to server was lost")
			else:
				raise Exception("Unknown command code")

	def handle_level_name(self, level_name):			
		return network.get_string(self.socket)
	
	def check_start_game(self):
		if select.select([self.socket],[],[],0)[0] == []:
			return False
		command = network.get_command_code(self.socket)
		if command == network.START_GAME_CODE:
			return True
		else:
			raise Exception("Unrecognized command code from server")
	
	def __del__(self):
		self.socket.close()
