import time
import sys

import pygame
from OpenGL import GL

import level
import menu_screen

min_frame_time = 0.01

class Game(object):
	def __init__(self):
		self.current_level = menu_screen.MenuScreen()
		self.last_time = time.time()
	
	def draw(self):
		GL.glClear(GL.GL_COLOR_BUFFER_BIT)
		GL.glEnable(GL.GL_BLEND)
		GL.glBlendFunc(GL.GL_SRC_ALPHA,GL.GL_ONE_MINUS_SRC_ALPHA)
		GL.glPushMatrix()
		GL.glScalef(2.0/800,-2.0/600,1)
		self.current_level.draw()
		GL.glPopMatrix()
	
	def do_frame(self):
		"Returns whether the game should end now."
		
		current_time = time.time()
		
		time_passed = current_time - self.last_time
		self.last_time = current_time
		self.current_level.do_frame(time_passed)
		frame_time = time.time()-self.last_time
		to_fill = max(0, min_frame_time-frame_time)
		if 0 != to_fill:
			time.sleep(to_fill)
		
		next_level = self.current_level.next_level
		if (next_level != self.current_level):
			print "Next screen: %s" % next_level
			self.current_level.dispose()
			self.current_level = next_level
		if self.current_level == None:
			return True
		return False
	
	def handle_event(self, event):
	    #QUIT	     none
		#ACTIVEEVENT	     gain, state
		#KEYDOWN	     unicode, key, mod
		#KEYUP	     key, mod
		#MOUSEMOTION	     pos, rel, buttons
		#MOUSEBUTTONUP    pos, button
		#MOUSEBUTTONDOWN  pos, button
		#JOYAXISMOTION    joy, axis, value
		#JOYBALLMOTION    joy, ball, rel
		#JOYHATMOTION     joy, hat, value
		#JOYBUTTONUP      joy, button
		#JOYBUTTONDOWN    joy, button
		#VIDEORESIZE      size, w, h
		#VIDEOEXPOSE      none
		#USEREVENT        code

		if event.type == pygame.QUIT:
			self.current_level.next_level = None
			return
		self.current_level.handle_event(event)
		